#!/bin/sh 

topfolder=`pwd`
timestamp=`date +%Y%m%d_%H%M%S` 
tmpfile=/tmp/testDSig.$timestamp-$$.tmp
logfile=/tmp/testDSig.$timestamp-$$.log
script="$0"
keysfile=$topfolder/keys.xml

printRes() {
    if [ $? = 0 ]; then
	echo "   OK"
    else 
        echo " Fail"
    fi
    if [ -f .memdump ] ; then 
	cat .memdump >> $logfile 
    fi
}

execDSigTest() {    
    file=$topfolder/$1      
    echo $1
    
    printf "    Verify existing signature                            "
    $topfolder/testDSig verify $2 $file.xml >> $logfile 2>> $logfile
    printRes 

    if [ -n "$3" ] ; then
	printf "    Create new signature                                 "
	$topfolder/testDSig sign $3 $file.tmpl > $tmpfile 2>> $logfile
	printRes
	
	if [ -n "$4" ] ; then 
	    printf "    Verify new signature                                 "
	    $topfolder/testDSig verify $4 $tmpfile >> $logfile 2>> $logfile
	    printRes
	fi
    fi
}

echo "--- testDSig started ($timestamp)"
echo "--- testDSig started ($timestamp)" >> $logfile

execDSigTest "merlin-xmldsig-twenty-three/signature-enveloped-dsa" \
    " " \
    "--privkey keys/dsakey.pem" \
    " " 
    
execDSigTest "merlin-xmldsig-twenty-three/signature-enveloping-dsa" \
    " " \
    "--privkey keys/dsakey.pem" \
    " " 
    
execDSigTest "merlin-xmldsig-twenty-three/signature-enveloping-b64-dsa" \
    " " \
    "--privkey keys/dsakey.pem" \
    " " 
    
execDSigTest "merlin-xmldsig-twenty-three/signature-enveloping-hmac-sha1-40" \
    "--hmackey keys/hmackey.bin" \
    "--hmackey keys/hmackey.bin" \
    "--hmackey keys/hmackey.bin" 
    
execDSigTest "merlin-xmldsig-twenty-three/signature-enveloping-hmac-sha1" \
    "--hmackey keys/hmackey.bin" \
    "--hmackey keys/hmackey.bin" \
    "--hmackey keys/hmackey.bin" 

execDSigTest "merlin-xmldsig-twenty-three/signature-enveloping-rsa" \
    " " \
    "--privkey keys/rsakey.pem" \
    " " 
    
execDSigTest "merlin-xmldsig-twenty-three/signature-external-b64-dsa" \
    " " \
    "--privkey keys/dsakey.pem" \
    " " 
    
execDSigTest "merlin-xmldsig-twenty-three/signature-external-dsa" \
    " " \
    "--privkey keys/dsakey.pem" \
    " " 

execDSigTest "merlin-xmldsig-twenty-three/signature-keyname" \
    "--pubkey:Lugh merlin-xmldsig-twenty-three/certs/lugh.key" \
    "--privkey:test-dsa keys/dsakey.pem" \
    "--privkey:test-dsa keys/dsakey.pem"

execDSigTest "merlin-xmldsig-twenty-three/signature-x509-crt" \
    "--CAfile merlin-xmldsig-twenty-three/certs/ca.pem" \
    "--privkey keys/dsakey.pem,keys/dsacert.pem,keys/ca2cert.pem"\
    "--CAfile keys/cacert.pem"

execDSigTest "merlin-xmldsig-twenty-three/signature-x509-sn" \
    "--CAfile merlin-xmldsig-twenty-three/certs/ca.pem --cert merlin-xmldsig-twenty-three/certs/badb.pem" \
    "--privkey keys/dsakey.pem,keys/dsacert.pem,keys/ca2cert.pem"\
    "--CAfile keys/cacert.pem"

execDSigTest "merlin-xmldsig-twenty-three/signature-x509-is" \
    "--CAfile merlin-xmldsig-twenty-three/certs/ca.pem --cert merlin-xmldsig-twenty-three/certs/macha.pem" \
    "--privkey keys/dsakey.pem,keys/dsacert.pem,keys/ca2cert.pem"\
    "--CAfile keys/cacert.pem"

execDSigTest "merlin-xmldsig-twenty-three/signature-x509-ski" \
    "--CAfile merlin-xmldsig-twenty-three/certs/ca.pem --cert merlin-xmldsig-twenty-three/certs/nemain.pem" \
    "--privkey keys/dsakey.pem,keys/dsacert.pem,keys/ca2cert.pem"\
    "--CAfile keys/cacert.pem"

execDSigTest "merlin-xmldsig-twenty-three/signature-retrievalmethod-rawx509crt" \
    "--CAfile merlin-xmldsig-twenty-three/certs/ca.pem --cert merlin-xmldsig-twenty-three/certs/nemain.pem" \
    "--privkey keys/dsakey.pem"\
    "--CAfile keys/cacert.pem --CAfile keys/ca2cert.pem"
    
execDSigTest "merlin-xmldsig-twenty-three/signature" \
    "--CAfile merlin-xmldsig-twenty-three/certs/merlin.pem" \
    "--privkey keys/dsakey.pem,keys/dsacert.pem,keys/ca2cert.pem" \
    "--CAfile keys/cacert.pem --cert keys/ca2cert.pem"
    
execDSigTest "merlin-exc-c14n-one/exc-signature" \
    " " \
    "--privkey keys/dsakey.pem" \
    " " 
    
execDSigTest "aleksey-xmldsig-01/enveloping-dsa-x509chain" \
    "--CAfile keys/cacert.pem --keys-origins x509" \
    "--privkey keys/dsakey.pem,keys/dsacert.pem,keys/ca2cert.pem" \
    "--CAfile keys/cacert.pem --keys-origins x509"

execDSigTest "aleksey-xmldsig-01/enveloping-rsa-x509chain" \
    "--CAfile keys/cacert.pem --keys-origins x509" \
    "--privkey keys/rsakey.pem,keys/rsacert.pem,keys/ca2cert.pem" \
    "--CAfile keys/cacert.pem --keys-origins x509"

execDSigTest "aleksey-xmldsig-01/enveloping-hmac-ripemd160" \
    "--hmackey keys/hmackey.bin" \
    "--hmackey keys/hmackey.bin" \
    "--hmackey keys/hmackey.bin" 

execDSigTest "aleksey-xmldsig-01/enveloping-hmac-ripemd160-64" \
    "--hmackey keys/hmackey.bin" \
    "--hmackey keys/hmackey.bin" \
    "--hmackey keys/hmackey.bin" 

execDSigTest "aleksey-xmldsig-01/enveloping-hmac-md5" \
    "--hmackey keys/hmackey.bin" \
    "--hmackey keys/hmackey.bin" \
    "--hmackey keys/hmackey.bin" 

execDSigTest "aleksey-xmldsig-01/enveloping-hmac-md5-64" \
    "--hmackey keys/hmackey.bin" \
    "--hmackey keys/hmackey.bin" \
    "--hmackey keys/hmackey.bin" 

echo "--------- Negative Testing: next test MUST FAIL ----------"
execDSigTest "merlin-xmldsig-twenty-three/signature-x509-crt-crl" \
    "--CAfile merlin-xmldsig-twenty-three/certs/ca.pem"
    
rm -rf $tmpfile
echo "--- testDSig finished" >> $logfile
echo "--- testDSig finished"
echo "--- detailed log is written to  $logfile" 



#merlin-xmldsig-twenty-three/signature-retrievalmethod-rawx509crt.xml
