#!/bin/sh 

topfolder=`pwd`
timestamp=`date +%Y%m%d_%H%M%S` 
tmpfile=/tmp/testEnc.$timestamp-$$.tmp
logfile=/tmp/testEnc.$timestamp-$$.log
script="$0"
keysfile=$topfolder/keys.xml

printRes() {
    if [ $? = 0 ]; then
	echo "   OK"
    else 
        echo " Fail"
    fi
    if [ -f .memdump ] ; then 
	cat .memdump >> $logfile 
    fi
}

execEncTest() {    
    file=$topfolder/$1      
    echo $1
    
    printf "    Decrypt existing document                            "
    rm -f $tmpfile
    $topfolder/testEnc decrypt $2 $file.xml > $tmpfile 2>> $logfile
    if [ $? = 0 ]; then
	diff $file.data $tmpfile >> $logfile 2>> $logfile
	printRes 
    else 
	echo " Error"
    fi

    if [ -n "$3" ] ; then
	printf "    Encrypt document                                     "
	rm -f $tmpfile
	$topfolder/testEnc encrypt $3 $file.tmpl > $tmpfile 2>> $logfile
	printRes
	
	if [ -n "$4" ] ; then 
	    printf "    Decrypt new document                                 "
	    $topfolder/testEnc decrypt $4 $tmpfile > $tmpfile.2 2>> $logfile
	    if [ $? = 0 ]; then
		diff $file.data $tmpfile.2 >> $logfile 2>> $logfile
		printRes
    	    else 
		echo " Error"
	    fi
	fi
    fi
    rm -f $tmpfile $tmpfile.2
}

echo "--- testEnc started ($timestamp)"
echo "--- testEnc started ($timestamp)" >> $logfile

execEncTest "aleksey-xmlenc-01/enc-des3cbc-keyname" \
    "--keys keys/keys.xml" \
    "--keys keys.xml --data aleksey-xmlenc-01/enc-des3cbc-keyname.data" \
    "--keys keys.xml"

execEncTest "aleksey-xmlenc-01/enc-aes128cbc-keyname" \
    "--keys keys/keys.xml" \
    "--keys keys.xml --data aleksey-xmlenc-01/enc-aes128cbc-keyname.data" \
    "--keys keys.xml"

execEncTest "aleksey-xmlenc-01/enc-aes192cbc-keyname" \
    "--keys keys/keys.xml" \
    "--keys keys.xml --data aleksey-xmlenc-01/enc-aes192cbc-keyname.data" \
    "--keys keys.xml"

execEncTest "aleksey-xmlenc-01/enc-aes256cbc-keyname" \
    "--keys keys/keys.xml" \
    "--keys keys.xml --data aleksey-xmlenc-01/enc-aes256cbc-keyname.data" \
    "--keys keys.xml"

execEncTest "aleksey-xmlenc-01/enc-des3cbc-keyname-content" \
    "--keys keys/keys.xml" \
    "--keys keys.xml --node aleksey-xmlenc-01/enc-des3cbc-keyname-content.data#Test" \
    "--keys keys.xml"

execEncTest "aleksey-xmlenc-01/enc-des3cbc-keyname-element" \
    "--keys keys/keys.xml" \
    "--keys keys.xml --node aleksey-xmlenc-01/enc-des3cbc-keyname-element.data#Test" \
    "--keys keys.xml"

execEncTest "aleksey-xmlenc-01/enc-des3cbc-keyname-element-root" \
    "--keys keys/keys.xml" \
    "--keys keys.xml --node aleksey-xmlenc-01/enc-des3cbc-keyname-element-root.data#Test" \
    "--keys keys.xml"

execEncTest "aleksey-xmlenc-01/enc-des3cbc-aes192-keyname" \
    "--keys keys/keys.xml" \
    "--keys keys.xml --data aleksey-xmlenc-01/enc-des3cbc-aes192-keyname.data" \
    "--keys keys.xml"

# Merlin's tests
execEncTest "merlin-xmlenc-five/encrypt-data-aes128-cbc" \
    "--keys merlin-xmlenc-five/keys.xml" \
    "--keys merlin-xmlenc-five/keys.xml --data merlin-xmlenc-five/encrypt-data-aes128-cbc.data" \
    "--keys merlin-xmlenc-five/keys.xml"
execEncTest "merlin-xmlenc-five/encrypt-content-tripledes-cbc" \
    "--keys merlin-xmlenc-five/keys.xml" \
    "--keys merlin-xmlenc-five/keys.xml --node merlin-xmlenc-five/encrypt-content-tripledes-cbc.data#Payment" \
    "--keys merlin-xmlenc-five/keys.xml"
execEncTest "merlin-xmlenc-five/encrypt-content-aes256-cbc-prop" \
    "--keys merlin-xmlenc-five/keys.xml" \
    "--keys merlin-xmlenc-five/keys.xml --node merlin-xmlenc-five/encrypt-content-aes256-cbc-prop.data#Payment" \
    "--keys merlin-xmlenc-five/keys.xml"
execEncTest "merlin-xmlenc-five/encrypt-element-aes192-cbc-ref" \
    "--keys merlin-xmlenc-five/keys.xml"
execEncTest "merlin-xmlenc-five/encrypt-element-aes128-cbc-rsa-1_5" \
    "--privkey merlin-xmlenc-five/rsapriv.pem" \
    "--keys merlin-xmlenc-five/keys.xml --privkey merlin-xmlenc-five/rsapriv.pem --node merlin-xmlenc-five/encrypt-element-aes128-cbc-rsa-1_5.data#Purchase"  \
    "--privkey merlin-xmlenc-five/rsapriv.pem"
execEncTest "merlin-xmlenc-five/encrypt-data-tripledes-cbc-rsa-oaep-mgf1p" \
    "--privkey merlin-xmlenc-five/rsapriv.pem" \
    "--keys merlin-xmlenc-five/keys.xml --privkey merlin-xmlenc-five/rsapriv.pem --data merlin-xmlenc-five/encrypt-data-tripledes-cbc-rsa-oaep-mgf1p.data"  \
    "--privkey merlin-xmlenc-five/rsapriv.pem"


#merlin-xmlenc-five/decryption-transform-except.xml
#merlin-xmlenc-five/decryption-transform.xml
#merlin-xmlenc-five/encrypt-content-aes128-cbc-kw-aes192.xml
#merlin-xmlenc-five/encrypt-content-aes192-cbc-dh-sha512.xml
#merlin-xmlenc-five/encrypt-data-aes192-cbc-kw-aes256.xml
#merlin-xmlenc-five/encrypt-data-aes256-cbc-kw-tripledes.xml
#merlin-xmlenc-five/encrypt-data-tripledes-cbc-rsa-oaep-mgf1p-sha256.xml
#merlin-xmlenc-five/encrypt-element-aes256-cbc-carried-kw-aes256.xml
#merlin-xmlenc-five/encrypt-element-aes256-cbc-kw-aes256-dh-ripemd160.xml
#merlin-xmlenc-five/encrypt-element-aes256-cbc-retrieved-kw-aes256.xml
#merlin-xmlenc-five/encrypt-element-tripledes-cbc-kw-aes128.xml
#merlin-xmlenc-five/encsig-hmac-sha256-dh.xml
#merlin-xmlenc-five/encsig-hmac-sha256-kw-tripledes-dh.xml
#merlin-xmlenc-five/encsig-hmac-sha256-rsa-1_5.xml
#merlin-xmlenc-five/encsig-hmac-sha256-rsa-oaep-mgf1p.xml
#merlin-xmlenc-five/encsig-ripemd160-hmac-ripemd160-kw-tripledes.xml
#merlin-xmlenc-five/encsig-sha256-hmac-sha256-kw-aes128.xml
#merlin-xmlenc-five/encsig-sha384-hmac-sha384-kw-aes192.xml
#merlin-xmlenc-five/encsig-sha512-hmac-sha512-kw-aes256.xml


echo "--------- Negative Testing: Following tests MUST FAIL ----------"

    
rm -rf $tmpfile
echo "--- testEnc finished" >> $logfile
echo "--- testEnc finished"
echo "--- detailed log is written to  $logfile" 

#more $logfile

